from distutils.core import setup
  
setup(  
    name = "ynn",  
    version = "1.0.0",  
    py_modules = ['ynn'],
	author_email = "test@gmail.com",
	author = "test", 	
    url = "http://test.com",  
    description = "my first shared code", 
)
